@@ -1,13 +1,13 @@
 package App::DistUtils;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2017-01-15'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 
 our %dist_arg_single = (
     dist => {
-        schema => 'str*',
+        schema => 'perl::distname*',
         req => 1,
         pos => 0,
         completion => sub {
@@ -20,7 +20,7 @@ our %dist_arg_single = (
 
 our %dist_arg_multiple = (
     dist => {
-        schema => ['array*', of=>'str*', min_len=>1],
+        schema => ['array*', of=>'perl::distname*', min_len=>1],
         req => 1,
         pos => 0,
         greedy => 1,
@@ -47,7 +47,7 @@ App::DistUtils - Collection of utilities related to Perl distributions
 
 =head1 VERSION
 
-This document describes version 0.12 of App::DistUtils (from Perl distribution App-DistUtils), released on 2016-06-26.
+This document describes version 0.13 of App::DistUtils (from Perl distribution App-DistUtils), released on 2017-01-15.
 
 =head1 SYNOPSIS
 
@@ -62,6 +62,10 @@ distributions:
 
 =item * L<dist-dir>
 
+=item * L<dist-has-deb>
+
+=item * L<dist2deb>
+
 =item * L<dist2mod>
 
 =item * L<list-dist-contents>
@@ -142,7 +146,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
